summaryrefslogtreecommitdiffstats
path: root/src/upnp/exitoperation.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/upnp/exitoperation.h')
-rw-r--r--src/upnp/exitoperation.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/upnp/exitoperation.h b/src/upnp/exitoperation.h
index 4a27911..d969c6c 100644
--- a/src/upnp/exitoperation.h
+++ b/src/upnp/exitoperation.h
@@ -21,7 +21,7 @@
#define KTEXITOPERATION_H
#include <ntqobject.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
namespace kt
{
@@ -49,18 +49,18 @@ namespace kt
};
/**
* Exit operation which waits for a KIO::Job
*/
class ExitJobOperation : public ExitOperation
{
Q_OBJECT
public:
- ExitJobOperation(KIO::Job* j);
+ ExitJobOperation(TDEIO::Job* j);
virtual ~ExitJobOperation();
virtual bool deleteAllowed() const {return false;}
private slots:
- virtual void onResult(KIO::Job* j);
+ virtual void onResult(TDEIO::Job* j);
};
}
@@ -49,18 +49,18 @@ namespace kt
};
/**
- * Exit operation which waits for a KIO::Job
+ * Exit operation which waits for a TDEIO::Job
*/
class ExitJobOperation : public ExitOperation